@@ -26,6 +26,7 @@ class CodeGenerator(object):
     def __init__(self, cf):
         self.__cf = cf
         self.__current_filter_number = 0
+        self.__current_group_number = 0
 
     def __get_header_code(self):
         declaration_code = '/* Configuration code for this widget */' + eol
@@ -308,8 +309,8 @@ class CodeGenerator(object):
 
         if len(attributes) > 0:
             attributes_code += COMMENT_GROUPS + eol
-            gn = 0
             for a in attributes:
+                gn = self.__current_group_number
                 # Calls
                 lbl_call = f'{eol}{tab}.label({a.get_label})' if a.get_label != '' else ''
                 l_call = f'{eol}{tab}.limit({a.get_limit})' if a.get_limit is not None else ''
@@ -329,7 +330,7 @@ class CodeGenerator(object):
 
                 attributes_code += f'let group{gn} = cf.Attribute("{a.get_name}"){lbl_call}{l_call}{s_call}{f_call}' + eol
                 attributes_names += f'group{gn},'
-                gn += 1
+                self.__current_group_number += 1
 
         return [attributes_code, attributes_names]
 
@@ -437,7 +438,8 @@ class CodeGenerator(object):
             static_filters = prov.get_static_filters
             metrics = prov.get_metrics
             comparative_metrics = prov.get_comparative_metrics
-            attrs = prov.get_groups
+            groups = prov.get_groups
+            colgroups = prov.get_colgroups
             rows = prov.get_rows
             columns = prov.get_columns
             fields = prov.get_fields
@@ -478,9 +480,13 @@ class CodeGenerator(object):
             metrics_call = f'{eol}{tab}.metrics({metrics_name[:-1]})'
 
             # Attribute
-            attributes_code = self.__generate_attributes_code(attrs)
-            code += attributes_code[0]
-            attributes_call = f'{eol}{tab}.groupby({attributes_code[1][:-1]})' if attributes_code[1] != '' else ''
+            groups_code = self.__generate_attributes_code(groups)
+            code += groups_code[0]
+            groups_call = f'{eol}{tab}.groupby({groups_code[1][:-1]})' if groups_code[1] != '' else ''
+            # colgroupby
+            colgroups_code = self.__generate_attributes_code(colgroups)
+            code += colgroups_code[0]
+            colgroups_call = f'{eol}{tab}.colgroupby({colgroups_code[1][:-1]})' if colgroups_code[1] != '' else ''
             # Rows
             rows_code = self.__generate_rows_code(rows)
             # Columns
@@ -502,7 +508,7 @@ class CodeGenerator(object):
 
             code += declaration_extra
             code += COMMENT_DATA + eol
-            code += f'let myData = source{filters_call}{client_filters_call}{static_filters_call}{metrics_call}{attributes_call}{rows_code}{columns_code}{fields_code}{exclude_code};' + eol + eol
+            code += f'let myData = source{filters_call}{client_filters_call}{static_filters_call}{metrics_call}{groups_call}{colgroups_call}{rows_code}{columns_code}{fields_code}{exclude_code};' + eol + eol
             code += f'myData.graph("{chart}")'
             code += limit_code + location_code + precision_code + time_field_code
             code += set_statement + eol
