@@ -743,8 +743,8 @@ class Provider(object):
                             data = data.loc[mask].reset_index(drop=True)
                         elif f.get_operation in [cnts.TS, cnts.NOT_TS]:
                             flag = True if f.get_operation == cnts.TS else False
-                            data = data.loc[data[f.get_path].str.contains(
-                                '|'.join(map(re.escape, f.get_value))) == flag].reset_index(drop=True)
+                            data = data.loc[data[f.get_path].astype(str).str.contains(
+                                '|'.join(map(re.escape, list(map(str,f.get_value))))) == flag].reset_index(drop=True)
                         else:
                             raise Exception(
                                 f'Invalid filter operation {f.get_operation}. Use one of these: %s' % cnts.FILTER_OPERATIONS)
@@ -1279,7 +1279,7 @@ class Provider(object):
 
         final_query = f"""
         SELECT _sub1.{row_group.get_name}, _sub1.{col_group.get_name}, {', '.join(final_metrics_select)}, count
-        FROM 
+        FROM
         (
             SELECT _crossRow.{row_group.get_name}, _crossCol.{col_group.get_name}, _crossRow.{row_group_sort_by}, rank
             FROM (
@@ -1288,17 +1288,17 @@ class Provider(object):
                 ) _crossRow
                CROSS JOIN (
                     SELECT *, ROW_NUMBER() OVER(ORDER BY {col_group_sort_by} {sort_dir_col_group}) AS rank
-                    FROM col_group_query 
+                    FROM col_group_query
                     ORDER BY rank ASC
-               ) _crossCol   
+               ) _crossCol
             GROUP BY _crossRow.{row_group.get_name}, _crossCol.{col_group.get_name}, _crossRow.{row_group_sort_by}, rank
         ) _sub1
         LEFT JOIN
-        (			
+        (
             SELECT _main.{row_group.get_name}, _main.{col_group.get_name}, _colGroupSub.rank, {', '.join(cross_row_metrics_select)}, count
             FROM
             (
-                SELECT *, ROW_NUMBER() OVER(ORDER BY {col_group_sort_by} {sort_dir_col_group}) AS rank 
+                SELECT *, ROW_NUMBER() OVER(ORDER BY {col_group_sort_by} {sort_dir_col_group}) AS rank
                 FROM col_group_query
             ) _colGroupSub
             LEFT JOIN
@@ -1310,8 +1310,8 @@ class Provider(object):
             on _colGroupSub.{col_group.get_name} = _main.{col_group.get_name}
             GROUP BY _main.{row_group.get_name}, _main.{col_group.get_name}, _colGroupSub.rank, {', '.join(cross_row_metrics_select)}, count
         ) _sub2
-        ON coalesce(_sub1.{row_group.get_name}, '&&null&&') = coalesce(_sub2.{row_group.get_name}, '&&null&&') and 
-        coalesce(_sub1.{col_group.get_name}, '&&null&&') = coalesce(_sub2.{col_group.get_name}, '&&null&&') 
+        ON coalesce(_sub1.{row_group.get_name}, '&&null&&') = coalesce(_sub2.{row_group.get_name}, '&&null&&') and
+        coalesce(_sub1.{col_group.get_name}, '&&null&&') = coalesce(_sub2.{col_group.get_name}, '&&null&&')
         ORDER BY _sub1.{row_group_sort_by} {sort_dir_row_group}, _sub1.rank ASC
         """
 
@@ -1350,14 +1350,21 @@ class Provider(object):
 
     def __process_boxplot__(self):
         try:
-            if len(self.__groups) > 0:
-                if len(self.__metrics) > 0:
+            if len(self.__metrics) > 0:
+                m = self.__metrics[0]
+                merge = None
+                response_name = 'default'
+                response = {
+                    'data': [],
+                    "visualization": self.__visualization
+                }
+
+                if len(self.__groups) > 0:
                     g = self.__groups[0]
+                    response_name = g.get_name
                     limit = g.get_limit
                     asc = True if g.get_sort.get('dir') == cnts.ASC else False
 
-                    m = self.__metrics[0]
-
                     group1 = self.__data.groupby([g.get_name]).agg({m.name: [quantile_0]}).reset_index()
                     group1.columns = [sanitize('_'.join(filter(None, x))) for x in group1.columns]
 
@@ -1379,11 +1386,6 @@ class Provider(object):
                     merge = pd.merge(merge, group5, on=sanitize(g.get_name))
                     merge = merge.sort_values([sanitize(g.get_name)], ascending=[asc]).iloc[:limit].reset_index(drop=True)
 
-                    response = {
-                        'data': [],
-                        "visualization": self.__visualization
-                    }
-
                     for row in merge.itertuples():
                         row = row._asdict()
                         current_metrics = {}
@@ -1405,17 +1407,52 @@ class Provider(object):
                                 current_metrics[met.name]['percentile100'] = q_100 if not np.isnan(q_100) else None
 
                         response.get('data').append({
-                            'group': [str(row[sanitize(g.get_name)])],
+                            'group': [str(row[sanitize(response_name)])],
                             'current': {
                                 'metrics': current_metrics
                             }
                         })
-
                     return json.dumps({'data': response})
                 else:
-                    raise Exception('Provide a metric to be able to run the boxplot query.')
+                    group1 = self.__data.agg({m.name: [quantile_0]}).reset_index()
+                    group1.columns = [sanitize('_'.join(filter(None, x))) for x in group1.columns]
+
+                    group2 = self.__data.agg({m.name: [quantile_25]}).reset_index()
+                    group2.columns = [sanitize('_'.join(filter(None, x))) for x in group2.columns]
+
+                    group3 = self.__data.agg({m.name: [quantile_50]}).reset_index()
+                    group3.columns = [sanitize('_'.join(filter(None, x))) for x in group3.columns]
+
+                    group4 = self.__data.agg({m.name: [quantile_75]}).reset_index()
+                    group4.columns = [sanitize('_'.join(filter(None, x))) for x in group4.columns]
+
+                    group5 = self.__data.agg({m.name: [quantile_100]}).reset_index()
+                    group5.columns = [sanitize('_'.join(filter(None, x))) for x in group5.columns]
+
+                    q_0 = round(float(group1.get(sanitize('_'.join(filter(None, m.name))))[0]), 2)
+                    q_25 = round(float(group2.get(sanitize('_'.join(filter(None, m.name))))[0]), 2)
+                    q_50 = round(float(group3.get(sanitize('_'.join(filter(None, m.name))))[0]), 2)
+                    q_75 = round(float(group4.get(sanitize('_'.join(filter(None, m.name))))[0]), 2)
+                    q_100 = round(float(group5.get(sanitize('_'.join(filter(None, m.name))))[0]), 2)
+
+                    current_metrics = {}
+                    current_metrics[m.name] = {}
+
+                    current_metrics[m.name]['percentile0'] = q_0 if not np.isnan(q_0) else None
+                    current_metrics[m.name]['percentile25'] = q_25 if not np.isnan(q_25) else None
+                    current_metrics[m.name]['percentile50'] = q_50 if not np.isnan(q_50) else None
+                    current_metrics[m.name]['percentile75'] = q_75 if not np.isnan(q_75) else None
+                    current_metrics[m.name]['percentile100'] = q_100 if not np.isnan(q_100) else None
+
+                    response.get('data').append({
+                        'group': [m.name],
+                        'current': {
+                            'metrics': current_metrics
+                        }
+                    })
+                    return json.dumps({'data': response})
             else:
-                raise Exception('Provide a group to be able to run the boxplot query.')
+                raise Exception('Provide a metric to be able to run the boxplot query.')
         except Exception as e:
             raise Exception(e)
 
